# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import core_x86_pb2 as core__x86__pb2
import core_arm_pb2 as core__arm__pb2
import core_aarch64_pb2 as core__aarch64__pb2
import core_ppc64_pb2 as core__ppc64__pb2
import core_s390_pb2 as core__s390__pb2
import rlimit_pb2 as rlimit__pb2
import timer_pb2 as timer__pb2
import creds_pb2 as creds__pb2
import sa_pb2 as sa__pb2
import siginfo_pb2 as siginfo__pb2
import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ncore.proto\x1a\x0e\x63ore-x86.proto\x1a\x0e\x63ore-arm.proto\x1a\x12\x63ore-aarch64.proto\x1a\x10\x63ore-ppc64.proto\x1a\x0f\x63ore-s390.proto\x1a\x0crlimit.proto\x1a\x0btimer.proto\x1a\x0b\x63reds.proto\x1a\x08sa.proto\x1a\rsiginfo.proto\x1a\nopts.proto\"\xb7\x03\n\x0ftask_core_entry\x12\x1c\n\ntask_state\x18\x01 \x02(\rB\x08\xd2?\x05\x32\x03gen\x12\x11\n\texit_code\x18\x02 \x02(\r\x12\x13\n\x0bpersonality\x18\x03 \x02(\r\x12\r\n\x05\x66lags\x18\x04 \x02(\r\x12\x19\n\nblk_sigset\x18\x05 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0c\n\x04\x63omm\x18\x06 \x02(\t\x12\"\n\x06timers\x18\x07 \x01(\x0b\x32\x12.task_timers_entry\x12$\n\x07rlimits\x18\x08 \x01(\x0b\x32\x13.task_rlimits_entry\x12\x0e\n\x06\x63g_set\x18\t \x01(\r\x12&\n\tsignals_s\x18\n \x01(\x0b\x32\x13.signal_queue_entry\x12\'\n\x10old_seccomp_mode\x18\x0b \x01(\x0e\x32\r.seccomp_mode\x12\x1a\n\x12old_seccomp_filter\x18\x0c \x01(\r\x12\x10\n\x08loginuid\x18\r \x01(\r\x12\x15\n\room_score_adj\x18\x0e \x01(\x05\x12\x1d\n\nsigactions\x18\x0f \x03(\x0b\x32\t.sa_entry\x12\x17\n\x0f\x63hild_subreaper\x18\x12 \x01(\x08\"\xe2\x01\n\x13task_kobj_ids_entry\x12\r\n\x05vm_id\x18\x01 \x02(\r\x12\x10\n\x08\x66iles_id\x18\x02 \x02(\r\x12\r\n\x05\x66s_id\x18\x03 \x02(\r\x12\x12\n\nsighand_id\x18\x04 \x02(\r\x12\x11\n\tpid_ns_id\x18\x05 \x01(\r\x12\x11\n\tnet_ns_id\x18\x06 \x01(\r\x12\x11\n\tipc_ns_id\x18\x07 \x01(\r\x12\x11\n\tuts_ns_id\x18\x08 \x01(\r\x12\x11\n\tmnt_ns_id\x18\t \x01(\r\x12\x12\n\nuser_ns_id\x18\n \x01(\r\x12\x14\n\x0c\x63group_ns_id\x18\x0b \x01(\r\"D\n\x10thread_sas_entry\x12\r\n\x05ss_sp\x18\x01 \x02(\x04\x12\x0f\n\x07ss_size\x18\x02 \x02(\x04\x12\x10\n\x08ss_flags\x18\x03 \x02(\r\"\xd3\x02\n\x11thread_core_entry\x12\x11\n\tfutex_rla\x18\x01 \x02(\x04\x12\x15\n\rfutex_rla_len\x18\x02 \x02(\r\x12\x12\n\nsched_nice\x18\x03 \x01(\x11\x12\x14\n\x0csched_policy\x18\x04 \x01(\r\x12\x12\n\nsched_prio\x18\x05 \x01(\r\x12\x12\n\nblk_sigset\x18\x06 \x01(\x04\x12\x1e\n\x03sas\x18\x07 \x01(\x0b\x32\x11.thread_sas_entry\x12\x12\n\npdeath_sig\x18\x08 \x01(\r\x12&\n\tsignals_p\x18\t \x01(\x0b\x32\x13.signal_queue_entry\x12\x1b\n\x05\x63reds\x18\n \x01(\x0b\x32\x0c.creds_entry\x12#\n\x0cseccomp_mode\x18\x0b \x01(\x0e\x32\r.seccomp_mode\x12\x16\n\x0eseccomp_filter\x18\x0c \x01(\r\x12\x0c\n\x04\x63omm\x18\r \x01(\t\"4\n\x12task_rlimits_entry\x12\x1e\n\x07rlimits\x18\x01 \x03(\x0b\x32\r.rlimit_entry\"\xa2\x03\n\ncore_entry\x12 \n\x05mtype\x18\x01 \x02(\x0e\x32\x11.core_entry.march\x12%\n\x0bthread_info\x18\x02 \x01(\x0b\x32\x10.thread_info_x86\x12 \n\x06ti_arm\x18\x06 \x01(\x0b\x32\x10.thread_info_arm\x12(\n\nti_aarch64\x18\x08 \x01(\x0b\x32\x14.thread_info_aarch64\x12$\n\x08ti_ppc64\x18\t \x01(\x0b\x32\x12.thread_info_ppc64\x12\"\n\x07ti_s390\x18\n \x01(\x0b\x32\x11.thread_info_s390\x12\x1c\n\x02tc\x18\x03 \x01(\x0b\x32\x10.task_core_entry\x12!\n\x03ids\x18\x04 \x01(\x0b\x32\x14.task_kobj_ids_entry\x12\'\n\x0bthread_core\x18\x05 \x01(\x0b\x32\x12.thread_core_entry\"K\n\x05march\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06X86_64\x10\x01\x12\x07\n\x03\x41RM\x10\x02\x12\x0b\n\x07\x41\x41RCH64\x10\x03\x12\t\n\x05PPC64\x10\x04\x12\x08\n\x04S390\x10\x05*4\n\x0cseccomp_mode\x12\x0c\n\x08\x64isabled\x10\x00\x12\n\n\x06strict\x10\x01\x12\n\n\x06\x66ilter\x10\x02')
  ,
  dependencies=[core__x86__pb2.DESCRIPTOR,core__arm__pb2.DESCRIPTOR,core__aarch64__pb2.DESCRIPTOR,core__ppc64__pb2.DESCRIPTOR,core__s390__pb2.DESCRIPTOR,rlimit__pb2.DESCRIPTOR,timer__pb2.DESCRIPTOR,creds__pb2.DESCRIPTOR,sa__pb2.DESCRIPTOR,siginfo__pb2.DESCRIPTOR,opts__pb2.DESCRIPTOR,])

_SECCOMP_MODE = _descriptor.EnumDescriptor(
  name='seccomp_mode',
  full_name='seccomp_mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='disabled', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='strict', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='filter', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1736,
  serialized_end=1788,
)
_sym_db.RegisterEnumDescriptor(_SECCOMP_MODE)

seccomp_mode = enum_type_wrapper.EnumTypeWrapper(_SECCOMP_MODE)
disabled = 0
strict = 1
filter = 2


_CORE_ENTRY_MARCH = _descriptor.EnumDescriptor(
  name='march',
  full_name='core_entry.march',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='X86_64', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARM', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AARCH64', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PPC64', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='S390', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1659,
  serialized_end=1734,
)
_sym_db.RegisterEnumDescriptor(_CORE_ENTRY_MARCH)


_TASK_CORE_ENTRY = _descriptor.Descriptor(
  name='task_core_entry',
  full_name='task_core_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_state', full_name='task_core_entry.task_state', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0052\003gen')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='task_core_entry.exit_code', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='personality', full_name='task_core_entry.personality', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='task_core_entry.flags', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blk_sigset', full_name='task_core_entry.blk_sigset', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comm', full_name='task_core_entry.comm', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timers', full_name='task_core_entry.timers', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rlimits', full_name='task_core_entry.rlimits', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cg_set', full_name='task_core_entry.cg_set', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signals_s', full_name='task_core_entry.signals_s', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_seccomp_mode', full_name='task_core_entry.old_seccomp_mode', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_seccomp_filter', full_name='task_core_entry.old_seccomp_filter', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loginuid', full_name='task_core_entry.loginuid', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oom_score_adj', full_name='task_core_entry.oom_score_adj', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigactions', full_name='task_core_entry.sigactions', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child_subreaper', full_name='task_core_entry.child_subreaper', index=15,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=618,
)


_TASK_KOBJ_IDS_ENTRY = _descriptor.Descriptor(
  name='task_kobj_ids_entry',
  full_name='task_kobj_ids_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vm_id', full_name='task_kobj_ids_entry.vm_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='files_id', full_name='task_kobj_ids_entry.files_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs_id', full_name='task_kobj_ids_entry.fs_id', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sighand_id', full_name='task_kobj_ids_entry.sighand_id', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid_ns_id', full_name='task_kobj_ids_entry.pid_ns_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_ns_id', full_name='task_kobj_ids_entry.net_ns_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipc_ns_id', full_name='task_kobj_ids_entry.ipc_ns_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uts_ns_id', full_name='task_kobj_ids_entry.uts_ns_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mnt_ns_id', full_name='task_kobj_ids_entry.mnt_ns_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_ns_id', full_name='task_kobj_ids_entry.user_ns_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgroup_ns_id', full_name='task_kobj_ids_entry.cgroup_ns_id', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=847,
)


_THREAD_SAS_ENTRY = _descriptor.Descriptor(
  name='thread_sas_entry',
  full_name='thread_sas_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ss_sp', full_name='thread_sas_entry.ss_sp', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ss_size', full_name='thread_sas_entry.ss_size', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ss_flags', full_name='thread_sas_entry.ss_flags', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=917,
)


_THREAD_CORE_ENTRY = _descriptor.Descriptor(
  name='thread_core_entry',
  full_name='thread_core_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='futex_rla', full_name='thread_core_entry.futex_rla', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='futex_rla_len', full_name='thread_core_entry.futex_rla_len', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sched_nice', full_name='thread_core_entry.sched_nice', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sched_policy', full_name='thread_core_entry.sched_policy', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sched_prio', full_name='thread_core_entry.sched_prio', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blk_sigset', full_name='thread_core_entry.blk_sigset', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sas', full_name='thread_core_entry.sas', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdeath_sig', full_name='thread_core_entry.pdeath_sig', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signals_p', full_name='thread_core_entry.signals_p', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creds', full_name='thread_core_entry.creds', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seccomp_mode', full_name='thread_core_entry.seccomp_mode', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seccomp_filter', full_name='thread_core_entry.seccomp_filter', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comm', full_name='thread_core_entry.comm', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=920,
  serialized_end=1259,
)


_TASK_RLIMITS_ENTRY = _descriptor.Descriptor(
  name='task_rlimits_entry',
  full_name='task_rlimits_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rlimits', full_name='task_rlimits_entry.rlimits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1313,
)


_CORE_ENTRY = _descriptor.Descriptor(
  name='core_entry',
  full_name='core_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mtype', full_name='core_entry.mtype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thread_info', full_name='core_entry.thread_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ti_arm', full_name='core_entry.ti_arm', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ti_aarch64', full_name='core_entry.ti_aarch64', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ti_ppc64', full_name='core_entry.ti_ppc64', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ti_s390', full_name='core_entry.ti_s390', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tc', full_name='core_entry.tc', index=6,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='core_entry.ids', index=7,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thread_core', full_name='core_entry.thread_core', index=8,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CORE_ENTRY_MARCH,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1734,
)

_TASK_CORE_ENTRY.fields_by_name['timers'].message_type = timer__pb2._TASK_TIMERS_ENTRY
_TASK_CORE_ENTRY.fields_by_name['rlimits'].message_type = _TASK_RLIMITS_ENTRY
_TASK_CORE_ENTRY.fields_by_name['signals_s'].message_type = siginfo__pb2._SIGNAL_QUEUE_ENTRY
_TASK_CORE_ENTRY.fields_by_name['old_seccomp_mode'].enum_type = _SECCOMP_MODE
_TASK_CORE_ENTRY.fields_by_name['sigactions'].message_type = sa__pb2._SA_ENTRY
_THREAD_CORE_ENTRY.fields_by_name['sas'].message_type = _THREAD_SAS_ENTRY
_THREAD_CORE_ENTRY.fields_by_name['signals_p'].message_type = siginfo__pb2._SIGNAL_QUEUE_ENTRY
_THREAD_CORE_ENTRY.fields_by_name['creds'].message_type = creds__pb2._CREDS_ENTRY
_THREAD_CORE_ENTRY.fields_by_name['seccomp_mode'].enum_type = _SECCOMP_MODE
_TASK_RLIMITS_ENTRY.fields_by_name['rlimits'].message_type = rlimit__pb2._RLIMIT_ENTRY
_CORE_ENTRY.fields_by_name['mtype'].enum_type = _CORE_ENTRY_MARCH
_CORE_ENTRY.fields_by_name['thread_info'].message_type = core__x86__pb2._THREAD_INFO_X86
_CORE_ENTRY.fields_by_name['ti_arm'].message_type = core__arm__pb2._THREAD_INFO_ARM
_CORE_ENTRY.fields_by_name['ti_aarch64'].message_type = core__aarch64__pb2._THREAD_INFO_AARCH64
_CORE_ENTRY.fields_by_name['ti_ppc64'].message_type = core__ppc64__pb2._THREAD_INFO_PPC64
_CORE_ENTRY.fields_by_name['ti_s390'].message_type = core__s390__pb2._THREAD_INFO_S390
_CORE_ENTRY.fields_by_name['tc'].message_type = _TASK_CORE_ENTRY
_CORE_ENTRY.fields_by_name['ids'].message_type = _TASK_KOBJ_IDS_ENTRY
_CORE_ENTRY.fields_by_name['thread_core'].message_type = _THREAD_CORE_ENTRY
_CORE_ENTRY_MARCH.containing_type = _CORE_ENTRY
DESCRIPTOR.message_types_by_name['task_core_entry'] = _TASK_CORE_ENTRY
DESCRIPTOR.message_types_by_name['task_kobj_ids_entry'] = _TASK_KOBJ_IDS_ENTRY
DESCRIPTOR.message_types_by_name['thread_sas_entry'] = _THREAD_SAS_ENTRY
DESCRIPTOR.message_types_by_name['thread_core_entry'] = _THREAD_CORE_ENTRY
DESCRIPTOR.message_types_by_name['task_rlimits_entry'] = _TASK_RLIMITS_ENTRY
DESCRIPTOR.message_types_by_name['core_entry'] = _CORE_ENTRY
DESCRIPTOR.enum_types_by_name['seccomp_mode'] = _SECCOMP_MODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

task_core_entry = _reflection.GeneratedProtocolMessageType('task_core_entry', (_message.Message,), dict(
  DESCRIPTOR = _TASK_CORE_ENTRY,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:task_core_entry)
  ))
_sym_db.RegisterMessage(task_core_entry)

task_kobj_ids_entry = _reflection.GeneratedProtocolMessageType('task_kobj_ids_entry', (_message.Message,), dict(
  DESCRIPTOR = _TASK_KOBJ_IDS_ENTRY,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:task_kobj_ids_entry)
  ))
_sym_db.RegisterMessage(task_kobj_ids_entry)

thread_sas_entry = _reflection.GeneratedProtocolMessageType('thread_sas_entry', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_SAS_ENTRY,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:thread_sas_entry)
  ))
_sym_db.RegisterMessage(thread_sas_entry)

thread_core_entry = _reflection.GeneratedProtocolMessageType('thread_core_entry', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_CORE_ENTRY,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:thread_core_entry)
  ))
_sym_db.RegisterMessage(thread_core_entry)

task_rlimits_entry = _reflection.GeneratedProtocolMessageType('task_rlimits_entry', (_message.Message,), dict(
  DESCRIPTOR = _TASK_RLIMITS_ENTRY,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:task_rlimits_entry)
  ))
_sym_db.RegisterMessage(task_rlimits_entry)

core_entry = _reflection.GeneratedProtocolMessageType('core_entry', (_message.Message,), dict(
  DESCRIPTOR = _CORE_ENTRY,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:core_entry)
  ))
_sym_db.RegisterMessage(core_entry)


_TASK_CORE_ENTRY.fields_by_name['task_state'].has_options = True
_TASK_CORE_ENTRY.fields_by_name['task_state']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\0052\003gen'))
_TASK_CORE_ENTRY.fields_by_name['blk_sigset'].has_options = True
_TASK_CORE_ENTRY.fields_by_name['blk_sigset']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vma.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vma.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tvma.proto\x1a\nopts.proto\"\xfe\x01\n\tvma_entry\x12\x14\n\x05start\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x12\n\x03\x65nd\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\r\n\x05pgoff\x18\x03 \x02(\x04\x12\r\n\x05shmid\x18\x04 \x02(\x04\x12\x1c\n\x04prot\x18\x05 \x02(\rB\x0e\xd2?\x0b\x1a\tmmap.prot\x12\x1e\n\x05\x66lags\x18\x06 \x02(\rB\x0f\xd2?\x0c\x1a\nmmap.flags\x12 \n\x06status\x18\x07 \x02(\rB\x10\xd2?\r\x1a\x0bmmap.status\x12\n\n\x02\x66\x64\x18\x08 \x02(\x12\x12\x13\n\x04madv\x18\t \x01(\x04\x42\x05\xd2?\x02\x08\x01\x12\x16\n\x07\x66\x64\x66lags\x18\n \x01(\rB\x05\xd2?\x02\x08\x01\x12\x10\n\x08out_jail\x18\x0b \x01(\x08')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_VMA_ENTRY = _descriptor.Descriptor(
  name='vma_entry',
  full_name='vma_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='vma_entry.start', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='vma_entry.end', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pgoff', full_name='vma_entry.pgoff', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shmid', full_name='vma_entry.shmid', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prot', full_name='vma_entry.prot', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\013\032\tmmap.prot')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='vma_entry.flags', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\014\032\nmmap.flags')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='vma_entry.status', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\r\032\013mmap.status')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='vma_entry.fd', index=7,
      number=8, type=18, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='madv', full_name='vma_entry.madv', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fdflags', full_name='vma_entry.fdflags', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_jail', full_name='vma_entry.out_jail', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['vma_entry'] = _VMA_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

vma_entry = _reflection.GeneratedProtocolMessageType('vma_entry', (_message.Message,), dict(
  DESCRIPTOR = _VMA_ENTRY,
  __module__ = 'vma_pb2'
  # @@protoc_insertion_point(class_scope:vma_entry)
  ))
_sym_db.RegisterMessage(vma_entry)


_VMA_ENTRY.fields_by_name['start'].has_options = True
_VMA_ENTRY.fields_by_name['start']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_VMA_ENTRY.fields_by_name['end'].has_options = True
_VMA_ENTRY.fields_by_name['end']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_VMA_ENTRY.fields_by_name['prot'].has_options = True
_VMA_ENTRY.fields_by_name['prot']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\013\032\tmmap.prot'))
_VMA_ENTRY.fields_by_name['flags'].has_options = True
_VMA_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\014\032\nmmap.flags'))
_VMA_ENTRY.fields_by_name['status'].has_options = True
_VMA_ENTRY.fields_by_name['status']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\r\032\013mmap.status'))
_VMA_ENTRY.fields_by_name['madv'].has_options = True
_VMA_ENTRY.fields_by_name['madv']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_VMA_ENTRY.fields_by_name['fdflags'].has_options = True
_VMA_ENTRY.fields_by_name['fdflags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-x86.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-x86.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0e\x63ore-x86.proto\x1a\nopts.proto\"\x9c\x03\n\x13user_x86_regs_entry\x12\x0b\n\x03r15\x18\x01 \x02(\x04\x12\x0b\n\x03r14\x18\x02 \x02(\x04\x12\x0b\n\x03r13\x18\x03 \x02(\x04\x12\x0b\n\x03r12\x18\x04 \x02(\x04\x12\n\n\x02\x62p\x18\x05 \x02(\x04\x12\n\n\x02\x62x\x18\x06 \x02(\x04\x12\x0b\n\x03r11\x18\x07 \x02(\x04\x12\x0b\n\x03r10\x18\x08 \x02(\x04\x12\n\n\x02r9\x18\t \x02(\x04\x12\n\n\x02r8\x18\n \x02(\x04\x12\n\n\x02\x61x\x18\x0b \x02(\x04\x12\n\n\x02\x63x\x18\x0c \x02(\x04\x12\n\n\x02\x64x\x18\r \x02(\x04\x12\n\n\x02si\x18\x0e \x02(\x04\x12\n\n\x02\x64i\x18\x0f \x02(\x04\x12\x0f\n\x07orig_ax\x18\x10 \x02(\x04\x12\n\n\x02ip\x18\x11 \x02(\x04\x12\n\n\x02\x63s\x18\x12 \x02(\x04\x12\r\n\x05\x66lags\x18\x13 \x02(\x04\x12\n\n\x02sp\x18\x14 \x02(\x04\x12\n\n\x02ss\x18\x15 \x02(\x04\x12\x0f\n\x07\x66s_base\x18\x16 \x02(\x04\x12\x0f\n\x07gs_base\x18\x17 \x02(\x04\x12\n\n\x02\x64s\x18\x18 \x02(\x04\x12\n\n\x02\x65s\x18\x19 \x02(\x04\x12\n\n\x02\x66s\x18\x1a \x02(\x04\x12\n\n\x02gs\x18\x1b \x02(\x04\x12)\n\x04mode\x18\x1c \x01(\x0e\x32\x13.user_x86_regs_mode:\x06NATIVE\"\xb0\x01\n\x14user_x86_xsave_entry\x12\x11\n\txstate_bv\x18\x01 \x02(\x04\x12\x12\n\nymmh_space\x18\x02 \x03(\r\x12\x14\n\x0c\x62ndreg_state\x18\x03 \x03(\x04\x12\x14\n\x0c\x62ndcsr_state\x18\x04 \x03(\x04\x12\x12\n\nopmask_reg\x18\x05 \x03(\x04\x12\x11\n\tzmm_upper\x18\x06 \x03(\x04\x12\x10\n\x08hi16_zmm\x18\x07 \x03(\x04\x12\x0c\n\x04pkru\x18\x08 \x03(\r\"\xe4\x01\n\x15user_x86_fpregs_entry\x12\x0b\n\x03\x63wd\x18\x01 \x02(\r\x12\x0b\n\x03swd\x18\x02 \x02(\r\x12\x0b\n\x03twd\x18\x03 \x02(\r\x12\x0b\n\x03\x66op\x18\x04 \x02(\r\x12\x0b\n\x03rip\x18\x05 \x02(\x04\x12\x0b\n\x03rdp\x18\x06 \x02(\x04\x12\r\n\x05mxcsr\x18\x07 \x02(\r\x12\x12\n\nmxcsr_mask\x18\x08 \x02(\r\x12\x10\n\x08st_space\x18\t \x03(\r\x12\x11\n\txmm_space\x18\n \x03(\r\x12\x0f\n\x07padding\x18\x0b \x03(\r\x12$\n\x05xsave\x18\r \x01(\x0b\x32\x15.user_x86_xsave_entry\"\xe6\x01\n\x0buser_desc_t\x12\x14\n\x0c\x65ntry_number\x18\x01 \x02(\r\x12\x11\n\tbase_addr\x18\x02 \x02(\r\x12\r\n\x05limit\x18\x03 \x02(\r\x12\x11\n\tseg_32bit\x18\x04 \x02(\x08\x12\x12\n\ncontents_h\x18\x05 \x02(\x08\x12\x12\n\ncontents_l\x18\x06 \x02(\x08\x12\x1c\n\x0eread_exec_only\x18\x07 \x02(\x08:\x04true\x12\x16\n\x0elimit_in_pages\x18\x08 \x02(\x08\x12\x1d\n\x0fseg_not_present\x18\t \x02(\x08:\x04true\x12\x0f\n\x07useable\x18\n \x02(\x08\"\xa0\x01\n\x0fthread_info_x86\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12+\n\x06gpregs\x18\x02 \x02(\x0b\x32\x14.user_x86_regs_entryB\x05\xd2?\x02\x08\x01\x12&\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x16.user_x86_fpregs_entry\x12\x19\n\x03tls\x18\x04 \x03(\x0b\x32\x0c.user_desc_t*,\n\x12user_x86_regs_mode\x12\n\n\x06NATIVE\x10\x01\x12\n\n\x06\x43OMPAT\x10\x02')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])

_USER_X86_REGS_MODE = _descriptor.EnumDescriptor(
  name='user_x86_regs_mode',
  full_name='user_x86_regs_mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPAT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1251,
  serialized_end=1295,
)
_sym_db.RegisterEnumDescriptor(_USER_X86_REGS_MODE)

user_x86_regs_mode = enum_type_wrapper.EnumTypeWrapper(_USER_X86_REGS_MODE)
NATIVE = 1
COMPAT = 2



_USER_X86_REGS_ENTRY = _descriptor.Descriptor(
  name='user_x86_regs_entry',
  full_name='user_x86_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r15', full_name='user_x86_regs_entry.r15', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r14', full_name='user_x86_regs_entry.r14', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r13', full_name='user_x86_regs_entry.r13', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r12', full_name='user_x86_regs_entry.r12', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bp', full_name='user_x86_regs_entry.bp', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bx', full_name='user_x86_regs_entry.bx', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r11', full_name='user_x86_regs_entry.r11', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r10', full_name='user_x86_regs_entry.r10', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r9', full_name='user_x86_regs_entry.r9', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r8', full_name='user_x86_regs_entry.r8', index=9,
      number=10, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ax', full_name='user_x86_regs_entry.ax', index=10,
      number=11, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cx', full_name='user_x86_regs_entry.cx', index=11,
      number=12, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dx', full_name='user_x86_regs_entry.dx', index=12,
      number=13, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='si', full_name='user_x86_regs_entry.si', index=13,
      number=14, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='di', full_name='user_x86_regs_entry.di', index=14,
      number=15, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_ax', full_name='user_x86_regs_entry.orig_ax', index=15,
      number=16, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='user_x86_regs_entry.ip', index=16,
      number=17, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cs', full_name='user_x86_regs_entry.cs', index=17,
      number=18, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='user_x86_regs_entry.flags', index=18,
      number=19, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sp', full_name='user_x86_regs_entry.sp', index=19,
      number=20, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ss', full_name='user_x86_regs_entry.ss', index=20,
      number=21, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs_base', full_name='user_x86_regs_entry.fs_base', index=21,
      number=22, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs_base', full_name='user_x86_regs_entry.gs_base', index=22,
      number=23, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ds', full_name='user_x86_regs_entry.ds', index=23,
      number=24, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='es', full_name='user_x86_regs_entry.es', index=24,
      number=25, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs', full_name='user_x86_regs_entry.fs', index=25,
      number=26, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gs', full_name='user_x86_regs_entry.gs', index=26,
      number=27, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='user_x86_regs_entry.mode', index=27,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=443,
)


_USER_X86_XSAVE_ENTRY = _descriptor.Descriptor(
  name='user_x86_xsave_entry',
  full_name='user_x86_xsave_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xstate_bv', full_name='user_x86_xsave_entry.xstate_bv', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ymmh_space', full_name='user_x86_xsave_entry.ymmh_space', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bndreg_state', full_name='user_x86_xsave_entry.bndreg_state', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bndcsr_state', full_name='user_x86_xsave_entry.bndcsr_state', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opmask_reg', full_name='user_x86_xsave_entry.opmask_reg', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zmm_upper', full_name='user_x86_xsave_entry.zmm_upper', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hi16_zmm', full_name='user_x86_xsave_entry.hi16_zmm', index=6,
      number=7, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkru', full_name='user_x86_xsave_entry.pkru', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=622,
)


_USER_X86_FPREGS_ENTRY = _descriptor.Descriptor(
  name='user_x86_fpregs_entry',
  full_name='user_x86_fpregs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cwd', full_name='user_x86_fpregs_entry.cwd', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swd', full_name='user_x86_fpregs_entry.swd', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twd', full_name='user_x86_fpregs_entry.twd', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fop', full_name='user_x86_fpregs_entry.fop', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rip', full_name='user_x86_fpregs_entry.rip', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rdp', full_name='user_x86_fpregs_entry.rdp', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mxcsr', full_name='user_x86_fpregs_entry.mxcsr', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mxcsr_mask', full_name='user_x86_fpregs_entry.mxcsr_mask', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='st_space', full_name='user_x86_fpregs_entry.st_space', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xmm_space', full_name='user_x86_fpregs_entry.xmm_space', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='user_x86_fpregs_entry.padding', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xsave', full_name='user_x86_fpregs_entry.xsave', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=853,
)


_USER_DESC_T = _descriptor.Descriptor(
  name='user_desc_t',
  full_name='user_desc_t',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry_number', full_name='user_desc_t.entry_number', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_addr', full_name='user_desc_t.base_addr', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='user_desc_t.limit', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seg_32bit', full_name='user_desc_t.seg_32bit', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contents_h', full_name='user_desc_t.contents_h', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contents_l', full_name='user_desc_t.contents_l', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_exec_only', full_name='user_desc_t.read_exec_only', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit_in_pages', full_name='user_desc_t.limit_in_pages', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seg_not_present', full_name='user_desc_t.seg_not_present', index=8,
      number=9, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useable', full_name='user_desc_t.useable', index=9,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=1086,
)


_THREAD_INFO_X86 = _descriptor.Descriptor(
  name='thread_info_x86',
  full_name='thread_info_x86',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_x86.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_x86.gpregs', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpregs', full_name='thread_info_x86.fpregs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls', full_name='thread_info_x86.tls', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1249,
)

_USER_X86_REGS_ENTRY.fields_by_name['mode'].enum_type = _USER_X86_REGS_MODE
_USER_X86_FPREGS_ENTRY.fields_by_name['xsave'].message_type = _USER_X86_XSAVE_ENTRY
_THREAD_INFO_X86.fields_by_name['gpregs'].message_type = _USER_X86_REGS_ENTRY
_THREAD_INFO_X86.fields_by_name['fpregs'].message_type = _USER_X86_FPREGS_ENTRY
_THREAD_INFO_X86.fields_by_name['tls'].message_type = _USER_DESC_T
DESCRIPTOR.message_types_by_name['user_x86_regs_entry'] = _USER_X86_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_x86_xsave_entry'] = _USER_X86_XSAVE_ENTRY
DESCRIPTOR.message_types_by_name['user_x86_fpregs_entry'] = _USER_X86_FPREGS_ENTRY
DESCRIPTOR.message_types_by_name['user_desc_t'] = _USER_DESC_T
DESCRIPTOR.message_types_by_name['thread_info_x86'] = _THREAD_INFO_X86
DESCRIPTOR.enum_types_by_name['user_x86_regs_mode'] = _USER_X86_REGS_MODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_x86_regs_entry = _reflection.GeneratedProtocolMessageType('user_x86_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_X86_REGS_ENTRY,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_x86_regs_entry)
  ))
_sym_db.RegisterMessage(user_x86_regs_entry)

user_x86_xsave_entry = _reflection.GeneratedProtocolMessageType('user_x86_xsave_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_X86_XSAVE_ENTRY,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_x86_xsave_entry)
  ))
_sym_db.RegisterMessage(user_x86_xsave_entry)

user_x86_fpregs_entry = _reflection.GeneratedProtocolMessageType('user_x86_fpregs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_X86_FPREGS_ENTRY,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_x86_fpregs_entry)
  ))
_sym_db.RegisterMessage(user_x86_fpregs_entry)

user_desc_t = _reflection.GeneratedProtocolMessageType('user_desc_t', (_message.Message,), dict(
  DESCRIPTOR = _USER_DESC_T,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:user_desc_t)
  ))
_sym_db.RegisterMessage(user_desc_t)

thread_info_x86 = _reflection.GeneratedProtocolMessageType('thread_info_x86', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_X86,
  __module__ = 'core_x86_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_x86)
  ))
_sym_db.RegisterMessage(thread_info_x86)


_THREAD_INFO_X86.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_X86.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_X86.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_X86.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tcp-stream.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tcp-stream.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10tcp-stream.proto\x1a\nopts.proto\"\xc8\x02\n\x10tcp_stream_entry\x12\x0f\n\x07inq_len\x18\x01 \x02(\r\x12\x0f\n\x07inq_seq\x18\x02 \x02(\r\x12\x10\n\x08outq_len\x18\x03 \x02(\r\x12\x10\n\x08outq_seq\x18\x04 \x02(\r\x12\x17\n\x08opt_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x12\n\nsnd_wscale\x18\x06 \x02(\r\x12\x11\n\tmss_clamp\x18\x07 \x02(\r\x12\x12\n\nrcv_wscale\x18\x08 \x01(\r\x12\x11\n\ttimestamp\x18\t \x01(\r\x12\x0c\n\x04\x63ork\x18\n \x01(\x08\x12\x0f\n\x07nodelay\x18\x0b \x01(\x08\x12\x10\n\x08unsq_len\x18\x0c \x01(\r\x12\x0f\n\x07snd_wl1\x18\r \x01(\r\x12\x0f\n\x07snd_wnd\x18\x0e \x01(\r\x12\x12\n\nmax_window\x18\x0f \x01(\r\x12\x0f\n\x07rcv_wnd\x18\x10 \x01(\r\x12\x0f\n\x07rcv_wup\x18\x11 \x01(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_TCP_STREAM_ENTRY = _descriptor.Descriptor(
  name='tcp_stream_entry',
  full_name='tcp_stream_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inq_len', full_name='tcp_stream_entry.inq_len', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inq_seq', full_name='tcp_stream_entry.inq_seq', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outq_len', full_name='tcp_stream_entry.outq_len', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outq_seq', full_name='tcp_stream_entry.outq_seq', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opt_mask', full_name='tcp_stream_entry.opt_mask', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snd_wscale', full_name='tcp_stream_entry.snd_wscale', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mss_clamp', full_name='tcp_stream_entry.mss_clamp', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rcv_wscale', full_name='tcp_stream_entry.rcv_wscale', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tcp_stream_entry.timestamp', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cork', full_name='tcp_stream_entry.cork', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodelay', full_name='tcp_stream_entry.nodelay', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsq_len', full_name='tcp_stream_entry.unsq_len', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snd_wl1', full_name='tcp_stream_entry.snd_wl1', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snd_wnd', full_name='tcp_stream_entry.snd_wnd', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_window', full_name='tcp_stream_entry.max_window', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rcv_wnd', full_name='tcp_stream_entry.rcv_wnd', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rcv_wup', full_name='tcp_stream_entry.rcv_wup', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=361,
)

DESCRIPTOR.message_types_by_name['tcp_stream_entry'] = _TCP_STREAM_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

tcp_stream_entry = _reflection.GeneratedProtocolMessageType('tcp_stream_entry', (_message.Message,), dict(
  DESCRIPTOR = _TCP_STREAM_ENTRY,
  __module__ = 'tcp_stream_pb2'
  # @@protoc_insertion_point(class_scope:tcp_stream_entry)
  ))
_sym_db.RegisterMessage(tcp_stream_entry)


_TCP_STREAM_ENTRY.fields_by_name['opt_mask'].has_options = True
_TCP_STREAM_ENTRY.fields_by_name['opt_mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cgroup.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cgroup.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0c\x63group.proto\"6\n\x0c\x63group_perms\x12\x0c\n\x04mode\x18\x01 \x02(\r\x12\x0b\n\x03uid\x18\x02 \x02(\r\x12\x0b\n\x03gid\x18\x03 \x02(\r\"N\n\x11\x63group_prop_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x1c\n\x05perms\x18\x03 \x01(\x0b\x32\r.cgroup_perms\"\x93\x01\n\x10\x63group_dir_entry\x12\x10\n\x08\x64ir_name\x18\x01 \x02(\t\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.cgroup_dir_entry\x12&\n\nproperties\x18\x03 \x03(\x0b\x32\x12.cgroup_prop_entry\x12 \n\tdir_perms\x18\x04 \x01(\x0b\x32\r.cgroup_perms\"F\n\x13\x63g_controller_entry\x12\x0e\n\x06\x63names\x18\x01 \x03(\t\x12\x1f\n\x04\x64irs\x18\x02 \x03(\x0b\x32\x11.cgroup_dir_entry\"B\n\x0f\x63g_member_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x13\n\x0b\x63gns_prefix\x18\x03 \x01(\r\":\n\x0c\x63g_set_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x1e\n\x04\x63tls\x18\x02 \x03(\x0b\x32\x10.cg_member_entry\"V\n\x0c\x63group_entry\x12\x1b\n\x04sets\x18\x01 \x03(\x0b\x32\r.cg_set_entry\x12)\n\x0b\x63ontrollers\x18\x02 \x03(\x0b\x32\x14.cg_controller_entry')
)




_CGROUP_PERMS = _descriptor.Descriptor(
  name='cgroup_perms',
  full_name='cgroup_perms',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='cgroup_perms.mode', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='cgroup_perms.uid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='cgroup_perms.gid', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=70,
)


_CGROUP_PROP_ENTRY = _descriptor.Descriptor(
  name='cgroup_prop_entry',
  full_name='cgroup_prop_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cgroup_prop_entry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='cgroup_prop_entry.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='perms', full_name='cgroup_prop_entry.perms', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=150,
)


_CGROUP_DIR_ENTRY = _descriptor.Descriptor(
  name='cgroup_dir_entry',
  full_name='cgroup_dir_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dir_name', full_name='cgroup_dir_entry.dir_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='cgroup_dir_entry.children', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='cgroup_dir_entry.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dir_perms', full_name='cgroup_dir_entry.dir_perms', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=300,
)


_CG_CONTROLLER_ENTRY = _descriptor.Descriptor(
  name='cg_controller_entry',
  full_name='cg_controller_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cnames', full_name='cg_controller_entry.cnames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirs', full_name='cg_controller_entry.dirs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=372,
)


_CG_MEMBER_ENTRY = _descriptor.Descriptor(
  name='cg_member_entry',
  full_name='cg_member_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cg_member_entry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='cg_member_entry.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cgns_prefix', full_name='cg_member_entry.cgns_prefix', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=440,
)


_CG_SET_ENTRY = _descriptor.Descriptor(
  name='cg_set_entry',
  full_name='cg_set_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='cg_set_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ctls', full_name='cg_set_entry.ctls', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=500,
)


_CGROUP_ENTRY = _descriptor.Descriptor(
  name='cgroup_entry',
  full_name='cgroup_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sets', full_name='cgroup_entry.sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controllers', full_name='cgroup_entry.controllers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=588,
)

_CGROUP_PROP_ENTRY.fields_by_name['perms'].message_type = _CGROUP_PERMS
_CGROUP_DIR_ENTRY.fields_by_name['children'].message_type = _CGROUP_DIR_ENTRY
_CGROUP_DIR_ENTRY.fields_by_name['properties'].message_type = _CGROUP_PROP_ENTRY
_CGROUP_DIR_ENTRY.fields_by_name['dir_perms'].message_type = _CGROUP_PERMS
_CG_CONTROLLER_ENTRY.fields_by_name['dirs'].message_type = _CGROUP_DIR_ENTRY
_CG_SET_ENTRY.fields_by_name['ctls'].message_type = _CG_MEMBER_ENTRY
_CGROUP_ENTRY.fields_by_name['sets'].message_type = _CG_SET_ENTRY
_CGROUP_ENTRY.fields_by_name['controllers'].message_type = _CG_CONTROLLER_ENTRY
DESCRIPTOR.message_types_by_name['cgroup_perms'] = _CGROUP_PERMS
DESCRIPTOR.message_types_by_name['cgroup_prop_entry'] = _CGROUP_PROP_ENTRY
DESCRIPTOR.message_types_by_name['cgroup_dir_entry'] = _CGROUP_DIR_ENTRY
DESCRIPTOR.message_types_by_name['cg_controller_entry'] = _CG_CONTROLLER_ENTRY
DESCRIPTOR.message_types_by_name['cg_member_entry'] = _CG_MEMBER_ENTRY
DESCRIPTOR.message_types_by_name['cg_set_entry'] = _CG_SET_ENTRY
DESCRIPTOR.message_types_by_name['cgroup_entry'] = _CGROUP_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

cgroup_perms = _reflection.GeneratedProtocolMessageType('cgroup_perms', (_message.Message,), dict(
  DESCRIPTOR = _CGROUP_PERMS,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cgroup_perms)
  ))
_sym_db.RegisterMessage(cgroup_perms)

cgroup_prop_entry = _reflection.GeneratedProtocolMessageType('cgroup_prop_entry', (_message.Message,), dict(
  DESCRIPTOR = _CGROUP_PROP_ENTRY,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cgroup_prop_entry)
  ))
_sym_db.RegisterMessage(cgroup_prop_entry)

cgroup_dir_entry = _reflection.GeneratedProtocolMessageType('cgroup_dir_entry', (_message.Message,), dict(
  DESCRIPTOR = _CGROUP_DIR_ENTRY,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cgroup_dir_entry)
  ))
_sym_db.RegisterMessage(cgroup_dir_entry)

cg_controller_entry = _reflection.GeneratedProtocolMessageType('cg_controller_entry', (_message.Message,), dict(
  DESCRIPTOR = _CG_CONTROLLER_ENTRY,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cg_controller_entry)
  ))
_sym_db.RegisterMessage(cg_controller_entry)

cg_member_entry = _reflection.GeneratedProtocolMessageType('cg_member_entry', (_message.Message,), dict(
  DESCRIPTOR = _CG_MEMBER_ENTRY,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cg_member_entry)
  ))
_sym_db.RegisterMessage(cg_member_entry)

cg_set_entry = _reflection.GeneratedProtocolMessageType('cg_set_entry', (_message.Message,), dict(
  DESCRIPTOR = _CG_SET_ENTRY,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cg_set_entry)
  ))
_sym_db.RegisterMessage(cg_set_entry)

cgroup_entry = _reflection.GeneratedProtocolMessageType('cgroup_entry', (_message.Message,), dict(
  DESCRIPTOR = _CGROUP_ENTRY,
  __module__ = 'cgroup_pb2'
  # @@protoc_insertion_point(class_scope:cgroup_entry)
  ))
_sym_db.RegisterMessage(cgroup_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rlimit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rlimit.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0crlimit.proto\"(\n\x0crlimit_entry\x12\x0b\n\x03\x63ur\x18\x01 \x02(\x04\x12\x0b\n\x03max\x18\x02 \x02(\x04')
)




_RLIMIT_ENTRY = _descriptor.Descriptor(
  name='rlimit_entry',
  full_name='rlimit_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cur', full_name='rlimit_entry.cur', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='rlimit_entry.max', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=56,
)

DESCRIPTOR.message_types_by_name['rlimit_entry'] = _RLIMIT_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

rlimit_entry = _reflection.GeneratedProtocolMessageType('rlimit_entry', (_message.Message,), dict(
  DESCRIPTOR = _RLIMIT_ENTRY,
  __module__ = 'rlimit_pb2'
  # @@protoc_insertion_point(class_scope:rlimit_entry)
  ))
_sym_db.RegisterMessage(rlimit_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eventpoll.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eventpoll.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0f\x65ventpoll.proto\x1a\nfown.proto\"u\n\x13\x65ventpoll_tfd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03tfd\x18\x02 \x02(\r\x12\x0e\n\x06\x65vents\x18\x03 \x02(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x04\x12\x0b\n\x03\x64\x65v\x18\x05 \x01(\r\x12\r\n\x05inode\x18\x06 \x01(\x04\x12\x0b\n\x03pos\x18\x07 \x01(\x04\"o\n\x14\x65ventpoll_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12!\n\x03tfd\x18\x04 \x03(\x0b\x32\x14.eventpoll_tfd_entry')
  ,
  dependencies=[fown__pb2.DESCRIPTOR,])




_EVENTPOLL_TFD_ENTRY = _descriptor.Descriptor(
  name='eventpoll_tfd_entry',
  full_name='eventpoll_tfd_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eventpoll_tfd_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tfd', full_name='eventpoll_tfd_entry.tfd', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='eventpoll_tfd_entry.events', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='eventpoll_tfd_entry.data', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dev', full_name='eventpoll_tfd_entry.dev', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inode', full_name='eventpoll_tfd_entry.inode', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='eventpoll_tfd_entry.pos', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=148,
)


_EVENTPOLL_FILE_ENTRY = _descriptor.Descriptor(
  name='eventpoll_file_entry',
  full_name='eventpoll_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eventpoll_file_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='eventpoll_file_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='eventpoll_file_entry.fown', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tfd', full_name='eventpoll_file_entry.tfd', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=261,
)

_EVENTPOLL_FILE_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_EVENTPOLL_FILE_ENTRY.fields_by_name['tfd'].message_type = _EVENTPOLL_TFD_ENTRY
DESCRIPTOR.message_types_by_name['eventpoll_tfd_entry'] = _EVENTPOLL_TFD_ENTRY
DESCRIPTOR.message_types_by_name['eventpoll_file_entry'] = _EVENTPOLL_FILE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

eventpoll_tfd_entry = _reflection.GeneratedProtocolMessageType('eventpoll_tfd_entry', (_message.Message,), dict(
  DESCRIPTOR = _EVENTPOLL_TFD_ENTRY,
  __module__ = 'eventpoll_pb2'
  # @@protoc_insertion_point(class_scope:eventpoll_tfd_entry)
  ))
_sym_db.RegisterMessage(eventpoll_tfd_entry)

eventpoll_file_entry = _reflection.GeneratedProtocolMessageType('eventpoll_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _EVENTPOLL_FILE_ENTRY,
  __module__ = 'eventpoll_pb2'
  # @@protoc_insertion_point(class_scope:eventpoll_file_entry)
  ))
_sym_db.RegisterMessage(eventpoll_file_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cpuinfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cpuinfo.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rcpuinfo.proto\"\xa3\x02\n\x11\x63puinfo_x86_entry\x12,\n\tvendor_id\x18\x01 \x02(\x0e\x32\x19.cpuinfo_x86_entry.vendor\x12\x12\n\ncpu_family\x18\x02 \x02(\r\x12\r\n\x05model\x18\x03 \x02(\r\x12\x10\n\x08stepping\x18\x04 \x02(\r\x12\x16\n\x0e\x63\x61pability_ver\x18\x05 \x02(\r\x12\x12\n\ncapability\x18\x06 \x03(\r\x12\x10\n\x08model_id\x18\x07 \x01(\t\x12\x16\n\x0exfeatures_mask\x18\x08 \x01(\x04\x12\x12\n\nxsave_size\x18\t \x01(\r\x12\x16\n\x0exsave_size_max\x18\n \x01(\r\")\n\x06vendor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05INTEL\x10\x01\x12\x07\n\x03\x41MD\x10\x02\"\x84\x01\n\x13\x63puinfo_ppc64_entry\x12/\n\x06\x65ndian\x18\x01 \x02(\x0e\x32\x1f.cpuinfo_ppc64_entry.endianness\x12\r\n\x05hwcap\x18\x02 \x03(\x04\"-\n\nendianness\x12\r\n\tBIGENDIAN\x10\x00\x12\x10\n\x0cLITTLEENDIAN\x10\x01\"#\n\x12\x63puinfo_s390_entry\x12\r\n\x05hwcap\x18\x02 \x03(\x04\"\x8a\x01\n\rcpuinfo_entry\x12%\n\tx86_entry\x18\x01 \x03(\x0b\x32\x12.cpuinfo_x86_entry\x12)\n\x0bppc64_entry\x18\x02 \x03(\x0b\x32\x14.cpuinfo_ppc64_entry\x12\'\n\ns390_entry\x18\x03 \x03(\x0b\x32\x13.cpuinfo_s390_entry')
)



_CPUINFO_X86_ENTRY_VENDOR = _descriptor.EnumDescriptor(
  name='vendor',
  full_name='cpuinfo_x86_entry.vendor',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMD', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=268,
  serialized_end=309,
)
_sym_db.RegisterEnumDescriptor(_CPUINFO_X86_ENTRY_VENDOR)

_CPUINFO_PPC64_ENTRY_ENDIANNESS = _descriptor.EnumDescriptor(
  name='endianness',
  full_name='cpuinfo_ppc64_entry.endianness',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BIGENDIAN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LITTLEENDIAN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=399,
  serialized_end=444,
)
_sym_db.RegisterEnumDescriptor(_CPUINFO_PPC64_ENTRY_ENDIANNESS)


_CPUINFO_X86_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_x86_entry',
  full_name='cpuinfo_x86_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='cpuinfo_x86_entry.vendor_id', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_family', full_name='cpuinfo_x86_entry.cpu_family', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='cpuinfo_x86_entry.model', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepping', full_name='cpuinfo_x86_entry.stepping', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capability_ver', full_name='cpuinfo_x86_entry.capability_ver', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capability', full_name='cpuinfo_x86_entry.capability', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cpuinfo_x86_entry.model_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xfeatures_mask', full_name='cpuinfo_x86_entry.xfeatures_mask', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xsave_size', full_name='cpuinfo_x86_entry.xsave_size', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xsave_size_max', full_name='cpuinfo_x86_entry.xsave_size_max', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CPUINFO_X86_ENTRY_VENDOR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=309,
)


_CPUINFO_PPC64_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_ppc64_entry',
  full_name='cpuinfo_ppc64_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endian', full_name='cpuinfo_ppc64_entry.endian', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hwcap', full_name='cpuinfo_ppc64_entry.hwcap', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CPUINFO_PPC64_ENTRY_ENDIANNESS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=444,
)


_CPUINFO_S390_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_s390_entry',
  full_name='cpuinfo_s390_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hwcap', full_name='cpuinfo_s390_entry.hwcap', index=0,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=481,
)


_CPUINFO_ENTRY = _descriptor.Descriptor(
  name='cpuinfo_entry',
  full_name='cpuinfo_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x86_entry', full_name='cpuinfo_entry.x86_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ppc64_entry', full_name='cpuinfo_entry.ppc64_entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='s390_entry', full_name='cpuinfo_entry.s390_entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=622,
)

_CPUINFO_X86_ENTRY.fields_by_name['vendor_id'].enum_type = _CPUINFO_X86_ENTRY_VENDOR
_CPUINFO_X86_ENTRY_VENDOR.containing_type = _CPUINFO_X86_ENTRY
_CPUINFO_PPC64_ENTRY.fields_by_name['endian'].enum_type = _CPUINFO_PPC64_ENTRY_ENDIANNESS
_CPUINFO_PPC64_ENTRY_ENDIANNESS.containing_type = _CPUINFO_PPC64_ENTRY
_CPUINFO_ENTRY.fields_by_name['x86_entry'].message_type = _CPUINFO_X86_ENTRY
_CPUINFO_ENTRY.fields_by_name['ppc64_entry'].message_type = _CPUINFO_PPC64_ENTRY
_CPUINFO_ENTRY.fields_by_name['s390_entry'].message_type = _CPUINFO_S390_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_x86_entry'] = _CPUINFO_X86_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_ppc64_entry'] = _CPUINFO_PPC64_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_s390_entry'] = _CPUINFO_S390_ENTRY
DESCRIPTOR.message_types_by_name['cpuinfo_entry'] = _CPUINFO_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

cpuinfo_x86_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_x86_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_X86_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_x86_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_x86_entry)

cpuinfo_ppc64_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_ppc64_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_PPC64_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_ppc64_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_ppc64_entry)

cpuinfo_s390_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_s390_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_S390_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_s390_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_s390_entry)

cpuinfo_entry = _reflection.GeneratedProtocolMessageType('cpuinfo_entry', (_message.Message,), dict(
  DESCRIPTOR = _CPUINFO_ENTRY,
  __module__ = 'cpuinfo_pb2'
  # @@protoc_insertion_point(class_scope:cpuinfo_entry)
  ))
_sym_db.RegisterMessage(cpuinfo_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: creds.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='creds.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0b\x63reds.proto\"\x8f\x02\n\x0b\x63reds_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04\x65uid\x18\x03 \x02(\r\x12\x0c\n\x04\x65gid\x18\x04 \x02(\r\x12\x0c\n\x04suid\x18\x05 \x02(\r\x12\x0c\n\x04sgid\x18\x06 \x02(\r\x12\r\n\x05\x66suid\x18\x07 \x02(\r\x12\r\n\x05\x66sgid\x18\x08 \x02(\r\x12\x0f\n\x07\x63\x61p_inh\x18\t \x03(\r\x12\x0f\n\x07\x63\x61p_prm\x18\n \x03(\r\x12\x0f\n\x07\x63\x61p_eff\x18\x0b \x03(\r\x12\x0f\n\x07\x63\x61p_bnd\x18\x0c \x03(\r\x12\x0f\n\x07secbits\x18\r \x02(\r\x12\x0e\n\x06groups\x18\x0e \x03(\r\x12\x13\n\x0blsm_profile\x18\x0f \x01(\t\x12\x16\n\x0elsm_sockcreate\x18\x10 \x01(\t')
)




_CREDS_ENTRY = _descriptor.Descriptor(
  name='creds_entry',
  full_name='creds_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='creds_entry.uid', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='creds_entry.gid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='euid', full_name='creds_entry.euid', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egid', full_name='creds_entry.egid', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suid', full_name='creds_entry.suid', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sgid', full_name='creds_entry.sgid', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsuid', full_name='creds_entry.fsuid', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsgid', full_name='creds_entry.fsgid', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cap_inh', full_name='creds_entry.cap_inh', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cap_prm', full_name='creds_entry.cap_prm', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cap_eff', full_name='creds_entry.cap_eff', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cap_bnd', full_name='creds_entry.cap_bnd', index=11,
      number=12, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secbits', full_name='creds_entry.secbits', index=12,
      number=13, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='creds_entry.groups', index=13,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lsm_profile', full_name='creds_entry.lsm_profile', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lsm_sockcreate', full_name='creds_entry.lsm_sockcreate', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=287,
)

DESCRIPTOR.message_types_by_name['creds_entry'] = _CREDS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

creds_entry = _reflection.GeneratedProtocolMessageType('creds_entry', (_message.Message,), dict(
  DESCRIPTOR = _CREDS_ENTRY,
  __module__ = 'creds_pb2'
  # @@protoc_insertion_point(class_scope:creds_entry)
  ))
_sym_db.RegisterMessage(creds_entry)


# @@protoc_insertion_point(module_scope)
